Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2033)

Unified Diff: ash/common/system/tray/system_tray.h

Issue 2190773002: Fix Volume slider is captured in screenshot done in touchview mode (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: nits Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ash/common/system/chromeos/network/tray_sms.cc ('k') | ash/common/system/tray/system_tray.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ash/common/system/tray/system_tray.h
diff --git a/ash/common/system/tray/system_tray.h b/ash/common/system/tray/system_tray.h
index 9029cb16f70f1bdc8e728bd069cfb97fd7b382cf..6d08cebec4d38cdbad35fa905e98a9b83593320d 100644
--- a/ash/common/system/tray/system_tray.h
+++ b/ash/common/system/tray/system_tray.h
@@ -25,6 +25,7 @@ class SystemBubbleWrapper;
class SystemTrayDelegate;
class SystemTrayItem;
class TrayAccessibility;
+class TrayAudio;
class TrayCast;
class TrayDate;
class TrayUpdate;
@@ -74,8 +75,9 @@ class ASH_EXPORT SystemTray : public TrayBackgroundView,
// seconds.
void SetDetailedViewCloseDelay(int close_delay);
- // Hides the detailed view for |item|.
- void HideDetailedView(SystemTrayItem* item);
+ // Hides the detailed view for |item|. If |animate| is false, disable
+ // the hiding animation for hiding |item|.
+ void HideDetailedView(SystemTrayItem* item, bool animate);
// Shows the notification view for |item|.
void ShowNotificationView(SystemTrayItem* item);
@@ -121,6 +123,9 @@ class ASH_EXPORT SystemTray : public TrayBackgroundView,
// otherwise.
views::View* GetHelpButtonView() const;
+ // Returns TrayAudio object if present or null otherwise.
+ TrayAudio* GetTrayAudio() const;
+
// Accessors for testing.
// Returns true if the bubble exists.
@@ -247,7 +252,9 @@ class ASH_EXPORT SystemTray : public TrayBackgroundView,
// Note that the value is only valid when |system_bubble_| is true.
bool full_system_tray_menu_;
- TrayAccessibility* tray_accessibility_; // not owned
+ // These objects are not owned by this class.
+ TrayAccessibility* tray_accessibility_;
+ TrayAudio* tray_audio_; // May be null.
TrayCast* tray_cast_;
TrayDate* tray_date_;
TrayUpdate* tray_update_;
« no previous file with comments | « ash/common/system/chromeos/network/tray_sms.cc ('k') | ash/common/system/tray/system_tray.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698